@@ -9,7 +9,7 @@ from .config import (
     user_flags_to_config_dict, flatten_config_dict, function_args_to_config
 )
 from .logging import (
-    WandBLogger, prefix_metrics, open_file, load_pickle
+    WandBLogger, prefix_metrics, open_file, save_pickle, load_pickle
 )
 from .utils import (
     Timer, open_file
